﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[System.Serializable]
public class AxleInfo
{
    public WheelCollider Wheel;
    public bool motor;
    public bool steering;
}

public class Kinematic : MonoBehaviour
{
    public List<AxleInfo> axleInfos;

    public static float SteeringFrontLeft = 0 ;
    public static float SteeringFrontRight = 0;
    public static float SteeringRearLeft = 0;
    public static float SteeringRearRight = 0;
    public static float TorqueFrontLeft = 0;
    public static float TorqueFrontRight = 0;
    public static float TorqueRearLeft = 0;
    public static float TorqueRearRight = 0;

    // Finds the corresponding visual wheel
    // Correctly applies the transform
    public void ApplyLocalPositionToVisuals(WheelCollider collider)
    {
        if (collider.transform.childCount == 0)
        {
            return;
        }

        Transform visualWheel = collider.transform.GetChild(0);

        Vector3 position;
        Quaternion rotation;
        collider.GetWorldPose(out position, out rotation);

        visualWheel.transform.position = position;
        visualWheel.transform.rotation = rotation;
    }

    public void FixedUpdate()
    {
        
        foreach (AxleInfo axleInfo in axleInfos)
        {
            if (axleInfo.steering)
            {
                switch (axleInfo.Wheel.tag)
                {
                    case "Front_left":
                        axleInfo.Wheel.steerAngle = SteeringFrontLeft;
                        break;
                    case "Front_right":
                        axleInfo.Wheel.steerAngle = SteeringFrontRight;
                        break;
                    case "Rear_left":
                        axleInfo.Wheel.steerAngle = SteeringRearLeft;
                        break;
                    case "Rear_right":
                        axleInfo.Wheel.steerAngle = SteeringRearRight;
                        break;
                }
                   
            }

            if (axleInfo.motor)
            {
                switch (axleInfo.Wheel.tag)
                {
                    case "Front_left":
                        axleInfo.Wheel.motorTorque = TorqueFrontLeft;
                        break;
                    case "Front_right":
                        axleInfo.Wheel.motorTorque = TorqueFrontRight;
                        break;
                    case "Rear_left":
                        axleInfo.Wheel.motorTorque = TorqueRearLeft;
                        break;
                    case "Rear_right":
                        axleInfo.Wheel.motorTorque = TorqueRearRight;
                        break;
                }

            }

            ApplyLocalPositionToVisuals(axleInfo.Wheel);
        }

    } //end FixedUpdate

} //end CarController

